==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicColorChooserUI__24TabPaneListener.h <==
// class javax.swing.plaf.basic.BasicColorChooserUI$TabPaneListener

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 272bc423210ab597 javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener_H_
#define _JC_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_ChangeEvent$object;
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object;
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$sub_refs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$refs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$nonrefs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$object	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vmethods	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtable	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtype	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$method$_init$5fea946ba5b0bc9f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$object *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object *);
extern void _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$method$_init$0f04f2249340331d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$object *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__241$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vmethods	javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$refs {
    _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$sub_refs	javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$sub_nonrefs	javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$object {
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtype _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicColorChooserUI__24TabPaneListener.h <==
// class javax.swing.plaf.basic.BasicColorChooserUI$TabPaneListener

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class bc296a2b43fef8cd javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener_H_
#define _JC_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_event_ChangeEvent$object;
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object;
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__241$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$sub_refs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$refs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$nonrefs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$object	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vmethods	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtable	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtype	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$method$_init$5fea946ba5b0bc9f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$object *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$method$_init$0f04f2249340331d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$object *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__241$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vmethods	javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$refs {
    _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$sub_refs	javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$sub_nonrefs	javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$object {
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$vtype _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicColorChooserUI__24TabPaneListener_H_ */
